/*
	Scott Zirpolo
	22 October, 2012

	This code is free to copy and use.
*/

#include "OrbiterAPI.h"
#include "Orbitersdk.h"
#include "VesselAPI.h"
#include "Aeroshield.h"

Aeroshield::Aeroshield (OBJHANDLE hVessel, int flightmodel)
	: VESSEL3 (hVessel, flightmodel)
{
}

Aeroshield::~Aeroshield()
{
}

void Aeroshield::clbkLoadStateEx(FILEHANDLE scn, void *status)
{
	char *line;

	meshType = 1;

	while (oapiReadScenario_nextline(scn,line))
	{
		if (!_strnicmp(line, "TYPE", 4)) //0-2. 0:Small, 1:Medium, 2:Large
			sscanf(line+4, "%u", &meshType);
		else
			ParseScenarioLineEx(line, status);
	}

	switch (meshType)
	{
	case 0:
		size         = 51;
		mass         = 1000;
		pmi          = _V(10090.84, 10090.84, 278.57);
		cs           = _V(83.45, 83.45, 2255.12);
		cw[0]        = 200;
		cw[1]        = 200;
		cw[2]        = 8;
		cw[3]        = 8;
		rotResistance = 80;
		dockLocation = _V(0, 0, 99.6);
	case 1:
		size         = 107;
		mass         = 3500;
		pmi          = _V(558.13, 558.13, 1114.28); //PMI and CS need correction. I'm not sure where the numbers came from.
		cs           = _V(333.80, 333.80, 9020.50);
		cw[0]        = 500;
		cw[1]        = 500;
		cw[2]        = 10;
		cw[3]        = 10;
		rotResistance = 200;
		dockLocation = _V(0, 0, 99.8);
	case 2:
		size         = 161;
		mass         = 6500;
		pmi          = _V(41273.24, 41273.24, 2507.14);
		cs           = _V(750.90, 750.90, 20296.10);
		cw[0]        = 600;
		cw[1]        = 600;
		cw[2]        = 11;
		cw[3]        = 11;
		rotResistance = 300;
		dockLocation = _V(0, 0, 199.8);
	}

}

void Aeroshield::clbkSetClassCaps(FILEHANDLE cfg)
{
	SetSize(size);
	SetEmptyMass(mass);
	SetPMI(pmi);
	SetCrossSections(cs);
	SetCW(cw[0],cw[1],cw[2],cw[3]);
	SetRotDrag(_V(rotResistance,rotResistance,rotResistance));

	EnableTransponder(true);
	SetTransponderChannel(198);

	hardpoint = CreateDock(dockLocation, _V(0,0,-1),_V(0,1,0));

	MESHHANDLE msh_h;
	int msh_idh;
	
	switch (meshType)
	{
	case 0:
		SetMeshVisibilityMode(msh_idh=AddMesh(msh_h=oapiLoadMeshGlobal("Aeroshieldsmall")),3);
	case 1:
		SetMeshVisibilityMode(msh_idh=AddMesh(msh_h=oapiLoadMeshGlobal("Aeroshield")),3);
	case 2:
		SetMeshVisibilityMode(msh_idh=AddMesh(msh_h=oapiLoadMeshGlobal("Aeroshieldlarge")),3);
	}
}

void Aeroshield::clbkSaveState(FILEHANDLE scn)
{
	VESSEL3::SaveDefaultState(scn);

	oapiWriteScenario_int(scn,"TYPE",meshType);
}

DLLCLBK VESSEL *ovcInit (OBJHANDLE hVessel, int flightmodel)
{
	return new Aeroshield(hVessel, flightmodel);
}

DLLCLBK void ovcExit (VESSEL *vessel)
{
	if (vessel) delete (Aeroshield*)vessel;
}